% Capture frames from a camera to a Chronoptics Streaming format (CSF) file
%

fileName = "frames.csf"; % The filename to save
numFrames = 100; % The number of frames to capture
dropFrames = 100; % The number of frames to drop before capturing

% The serial number of the camera to connect to.
serial = '202001a';

proc = tof.ProcessingConfig();
proc.setMedianEnabled(true);
proc.setMedianSize(5);

cam = tof.KeaCamera(proc, serial);

cap_types = [tof.FrameType.PHASE, tof.FrameType.INTENSITY, tof.FrameType.Z];
tof.selectStreams(cam, cap_types);

% Init the CSF writer
writer = tof.createCsfWriterCamera(fileName, cam);

cam.start();
disp('Camera started');

for i = 1:dropFrames
    frames = cam.getFrames();
end

disp('Frames Dropped');

for i = 1:numFrames
    frames = cam.getFrames();

    for frame = frames
        writer.writeFrame(frame);
    end

end

disp("Capture finished")

cam.stop();
